@@ -1,11 +1,11 @@
 import warnings
 import sys
 import errno
-import functools
 import logging
 import socket
 import ssl
 import os
+import platform
 
 import pytest
 
@@ -28,6 +28,16 @@ VALID_SOURCE_ADDRESSES = [(("::1", 0), True), (("127.0.0.1", 0), False)]
 # RFC 3849: 2001:db8::/32 is for documentation only.
 INVALID_SOURCE_ADDRESSES = [("192.0.2.255", 0), ("2001:db8::1", 0)]
 
+# We use timeouts in three different ways in our tests
+#
+# 1. To make sure that the operation timeouts, we can use a short timeout.
+# 2. To make sure that the test does not hang even if the operation should succeed, we
+#    want to use a long timeout, even more so on CI where tests can be really slow
+# 3. To test our timeout logic by using two different values, eg. by using different
+#    values at the pool level and at the request level.
+SHORT_TIMEOUT = 0.001
+LONG_TIMEOUT = 0.5 if os.environ.get("CI") else 0.01
+
 
 def clear_warnings(cls=HTTPWarning):
     new_filters = []
@@ -46,7 +56,7 @@ def setUp():
 def onlyPy279OrNewer(test):
     """Skips this test unless you are on Python 2.7.9 or later."""
 
-    @functools.wraps(test)
+    @six.wraps(test)
     def wrapper(*args, **kwargs):
         msg = "{name} requires Python 2.7.9+ to run".format(name=test.__name__)
         if sys.version_info < (2, 7, 9):
@@ -59,7 +69,7 @@ def onlyPy279OrNewer(test):
 def onlyPy2(test):
     """Skips this test unless you are on Python 2.x"""
 
-    @functools.wraps(test)
+    @six.wraps(test)
     def wrapper(*args, **kwargs):
         msg = "{name} requires Python 2.x to run".format(name=test.__name__)
         if not six.PY2:
@@ -72,7 +82,7 @@ def onlyPy2(test):
 def onlyPy3(test):
     """Skips this test unless you are on Python3.x"""
 
-    @functools.wraps(test)
+    @six.wraps(test)
     def wrapper(*args, **kwargs):
         msg = "{name} requires Python3.x to run".format(name=test.__name__)
         if six.PY2:
@@ -82,6 +92,20 @@ def onlyPy3(test):
     return wrapper
 
 
+def notPyPy2(test):
+    """Skips this test on PyPy2"""
+
+    @six.wraps(test)
+    def wrapper(*args, **kwargs):
+        # https://github.com/testing-cabal/mock/issues/438
+        msg = "{} fails with PyPy 2 dues to funcsigs bugs".format(test.__name__)
+        if platform.python_implementation() == "PyPy" and sys.version_info[0] == 2:
+            pytest.xfail(msg)
+        return test(*args, **kwargs)
+
+    return wrapper
+
+
 def onlyBrotlipy():
     return pytest.mark.skipif(brotli is None, reason="only run if brotlipy is present")
 
@@ -95,7 +119,7 @@ def notBrotlipy():
 def notSecureTransport(test):
     """Skips this test when SecureTransport is in use."""
 
-    @functools.wraps(test)
+    @six.wraps(test)
     def wrapper(*args, **kwargs):
         msg = "{name} does not run with SecureTransport".format(name=test.__name__)
         if ssl_.IS_SECURETRANSPORT:
@@ -108,7 +132,7 @@ def notSecureTransport(test):
 def notOpenSSL098(test):
     """Skips this test for Python 3.4 and 3.5 macOS python.org distributions"""
 
-    @functools.wraps(test)
+    @six.wraps(test)
     def wrapper(*args, **kwargs):
         is_stdlib_ssl = not ssl_.IS_SECURETRANSPORT and not ssl_.IS_PYOPENSSL
         if is_stdlib_ssl and ssl.OPENSSL_VERSION == "OpenSSL 0.9.8zh 14 Jan 2016":
@@ -127,8 +151,8 @@ def requires_network(test):
     def _is_unreachable_err(err):
         return getattr(err, "errno", None) in (
             errno.ENETUNREACH,
-            errno.EHOSTUNREACH,
-        )  # For OSX
+            errno.EHOSTUNREACH,  # For OSX
+        )
 
     def _has_route():
         try:
@@ -143,7 +167,7 @@ def requires_network(test):
             else:
                 raise
 
-    @functools.wraps(test)
+    @six.wraps(test)
     def wrapper(*args, **kwargs):
         global _requires_network_has_route
 
@@ -162,7 +186,7 @@ def requires_network(test):
 
 
 def requires_ssl_context_keyfile_password(test):
-    @functools.wraps(test)
+    @six.wraps(test)
     def wrapper(*args, **kwargs):
         if (
             not ssl_.IS_PYOPENSSL and sys.version_info < (2, 7, 9)
@@ -184,7 +208,7 @@ def fails_on_travis_gce(test):
     https://github.com/urllib3/urllib3/pull/1475#issuecomment-440788064
     """
 
-    @functools.wraps(test)
+    @six.wraps(test)
     def wrapper(*args, **kwargs):
         if os.environ.get("TRAVIS_INFRA") in ("gce", "unknown"):
             pytest.xfail("%s is expected to fail on Travis GCE builds" % test.__name__)
